@@ -28,21 +28,21 @@ import re
 _pkg_config = {
     'arch':               '',
     'default_bin_dir':    '/usr/bin',
-    'default_mod_dir':    '/usr/lib/python3.4/site-packages',
-    'default_sip_dir':    '/usr/share/python3-sip',
+    'default_mod_dir':    '/usr/lib/python3.6/site-packages',
+    'default_sip_dir':    '/usr/share/sip',
     'deployment_target':  '',
     'platform':           'cygwin-g++',
-    'py_conf_inc_dir':    '/usr/include/python3.4m',
-    'py_inc_dir':         '/usr/include/python3.4m',
-    'py_lib_dir':         '/usr/lib/python3.4/config',
-    'py_version':         0x030403,
+    'py_conf_inc_dir':    '/usr/include/python3.6m',
+    'py_inc_dir':         '/usr/include/python3.6m',
+    'py_lib_dir':         '/usr/lib/python3.6/config',
+    'py_version':         0x030601,
     'qt_framework':       0,
-    'sip_bin':            '/usr/lib/python3.4/site-packages/sip',
-    'sip_config_args':    '-p cygwin-g++ -b /usr/lib/python3.4/site-packages -d /usr/lib/python3.4/site-packages -e /usr/include/python3.4m -v /usr/share/python3-sip CFLAGS+=-ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/build=/usr/src/debug/python3-sip-4.16.9-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/src/sip-4.16.9=/usr/src/debug/python3-sip-4.16.9-1 CXXFLAGS+=-ggdb -O2 -pipe -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/build=/usr/src/debug/python3-sip-4.16.9-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/src/sip-4.16.9=/usr/src/debug/python3-sip-4.16.9-1',
-    'sip_inc_dir':        '/usr/include/python3.4m',
-    'sip_mod_dir':        '/usr/lib/python3.4/site-packages',
-    'sip_version':        0x041009,
-    'sip_version_str':    '4.16.9',
+    'sip_bin':            '/usr/bin/sip',
+    'sip_config_args':    '-p cygwin-g++ -b /usr/bin -d /usr/lib/python3.6/site-packages -e /usr/include/python3.6m -v /usr/share/sip CFLAGS=-ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python-sip/python-sip-4.19.3-1.i686/build=/usr/src/debug/python-sip-4.19.3-1 -fdebug-prefix-map=/usr/src/ports/python-sip/python-sip-4.19.3-1.i686/src/sip-4.19.3=/usr/src/debug/python-sip-4.19.3-1 CXXFLAGS=-ggdb -O2 -pipe -fdebug-prefix-map=/usr/src/ports/python-sip/python-sip-4.19.3-1.i686/build=/usr/src/debug/python-sip-4.19.3-1 -fdebug-prefix-map=/usr/src/ports/python-sip/python-sip-4.19.3-1.i686/src/sip-4.19.3=/usr/src/debug/python-sip-4.19.3-1',
+    'sip_inc_dir':        '/usr/include/python3.6m',
+    'sip_mod_dir':        '/usr/lib/python3.6/site-packages',
+    'sip_version':        0x041303,
+    'sip_version_str':    '4.19.3',
     'universal':          ''
 }
 
@@ -50,7 +50,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-pipe -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/build=/usr/src/debug/python3-sip-4.16.9-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/src/sip-4.16.9=/usr/src/debug/python3-sip-4.16.9-1',
+    'CFLAGS':                   '-ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python-sip/python-sip-4.19.3-1.i686/build=/usr/src/debug/python-sip-4.19.3-1 -fdebug-prefix-map=/usr/src/ports/python-sip/python-sip-4.19.3-1.i686/src/sip-4.19.3=/usr/src/debug/python-sip-4.19.3-1',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
@@ -73,7 +73,7 @@ _default_macros = {
     'CONFIG':                   'qt warn_on release incremental link_prl',
     'COPY':                     'cp -f',
     'CXX':                      'g++',
-    'CXXFLAGS':                 '-pipe -ggdb -O2 -pipe -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/build=/usr/src/debug/python3-sip-4.16.9-1 -fdebug-prefix-map=/usr/src/ports/python3-sip/python3-sip-4.16.9-1.x86_64/src/sip-4.16.9=/usr/src/debug/python3-sip-4.16.9-1',
+    'CXXFLAGS':                 '-ggdb -O2 -pipe -fdebug-prefix-map=/usr/src/ports/python-sip/python-sip-4.19.3-1.i686/build=/usr/src/debug/python-sip-4.19.3-1 -fdebug-prefix-map=/usr/src/ports/python-sip/python-sip-4.19.3-1.i686/src/sip-4.19.3=/usr/src/debug/python-sip-4.19.3-1',
     'CXXFLAGS_APP':             '',
     'CXXFLAGS_CONSOLE':         '',
     'CXXFLAGS_DEBUG':           '-g',
@@ -1583,7 +1583,7 @@ class ModuleMakefile(Makefile):
     """
     def __init__(self, configuration, build_file, install_dir=None, static=0,
                  console=0, qt=0, opengl=0, threaded=0, warnings=1, debug=0,
-                 dir=None, makefile="Makefile", installs=None, strip=1,
+                 dir=None, makefile="Makefile", installs=None, strip=0,
                  export_all=0, universal=None, arch=None,
                  deployment_target=None):
         """Initialise an instance of a module Makefile.
@@ -1894,7 +1894,7 @@ class SIPModuleMakefile(ModuleMakefile):
     """
     def __init__(self, configuration, build_file, install_dir=None, static=0,
                  console=0, qt=0, opengl=0, threaded=0, warnings=1, debug=0,
-                 dir=None, makefile="Makefile", installs=None, strip=1,
+                 dir=None, makefile="Makefile", installs=None, strip=0,
                  export_all=0, universal=None, arch=None, prot_is_public=0,
                  deployment_target=None):
         """Initialise an instance of a SIP generated module Makefile.
